@@ -1780,6 +1780,7 @@ class NiceQuest(BaseModelORJson):
     chapterId: int
     chapterSubId: int
     chapterSubStr: str
+    giftIcon: HttpUrl | None = None
     gifts: list[NiceGift]
     releaseConditions: list[NiceQuestRelease]
     phases: list[int]
@@ -2153,6 +2154,12 @@ class NiceWarAdd(BaseModelORJson):
     endedAt: int
 
 
+class NiceWarQuestSelection(BaseModelORJson):
+    quest: NiceQuest
+    shortcutBanner: HttpUrl | None = None
+    priority: int
+
+
 class NiceWar(BaseModelORJson):
     id: int
     coordinates: list[list[Decimal]]
@@ -2180,6 +2187,7 @@ class NiceWar(BaseModelORJson):
     maps: list[NiceMap]
     spots: list[NiceSpot]
     spotRoads: list[NiceSpotRoad]
+    questSelections: list[NiceWarQuestSelection]
 
 
 class NiceAiAct(BaseModelORJson):
